==> gitinfo-8.x-1.5.tar.gz: gitinfo/tests/src/Functional/GitinfoTest.php <==
<?php

namespace Drupal\Tests\gitinfo\Functional;

use Drupal\Core\Url;
use Drupal\Tests\BrowserTestBase;

/**
 * Simple test to ensure that main page loads with module enabled.
 *
 * @group gitinfo
 */
class GitinfoTest extends BrowserTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = ['gitinfo'];

  /**
   * A user with permission to administer site configuration.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $user;

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();
    $this->user = $this->drupalCreateUser(['administer site configuration']);
    $this->drupalLogin($this->user);
  }

  /**
   * Test some pages.
   */
  public function testLoad() {
    // Test that the home page loads with a 200 response.
    $this->drupalGet(Url::fromRoute('<front>'));
    $this->assertSession()->statusCodeEquals(200);

    // Visit the Status report page that requires login with a url object.
    $url = Url::fromRoute('system.status');
    $this->drupalGet($url);
    $this->assertSession()->statusCodeEquals(200);

    // Test that the page contains the GIT info section.
    $this->assertSession()->pageTextContains('GIT info');
  }

  /**
   * Test form submission.
   */
  public function testFormSubmission() {
    // Get form and check it loads correctly.
    $url = Url::fromRoute('gitinfo.settings');
    $this->drupalGet($url);
    $this->assertSession()->statusCodeEquals(200);
    $this->assertText('Connect with remote repos');
    // Empty form submission. Check presence of the default value.
    $this->drupalPostForm(NULL, [], 'Save configuration');
    $this->assertText('vendor');
    // Form validation testing of a non-existing directory rejection.
    $edit = ['extra_folders' => '/non-existing/directory'];
    $this->drupalPostForm(NULL, $edit, 'Save configuration');
    $this->assertText('Directory /non-existing/directory does not exist.');
    // Form validation testing of a invalid characters rejection.
    $edit = ['extra_folders' => '', 'aggregate_folders' => 'some/invalid/ch@r@ter$'];
    $this->drupalPostForm(NULL, $edit, 'Save configuration');
    $this->assertText('Directory some/invalid/ch@r@ter$ is invalid.');
    // A correct form submission.
    $edit = ['extra_folders' => '', 'aggregate_folders' => 'vendor'];
    $this->drupalPostForm(NULL, $edit, 'Save configuration');
    $this->assertText('The configuration options have been saved.');
  }

}

==> gitinfo-8.x-1.6.tar.gz: gitinfo/tests/src/Functional/GitinfoTest.php <==
<?php

namespace Drupal\Tests\gitinfo\Functional;

use Drupal\Core\Url;
use Drupal\Tests\BrowserTestBase;

/**
 * Simple test to ensure that main page loads with module enabled.
 *
 * @group gitinfo
 */
class GitinfoTest extends BrowserTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = ['gitinfo'];

  /**
   * A user with permission to administer site configuration.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $user;

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();
    $this->user = $this->drupalCreateUser(['administer site configuration']);
    $this->drupalLogin($this->user);
  }

  /**
   * Test some pages.
   */
  public function testLoad() {
    // Test that the home page loads with a 200 response.
    $this->drupalGet(Url::fromRoute('<front>'));
    $this->assertSession()->statusCodeEquals(200);

    // Visit the Status report page that requires login with a url object.
    $url = Url::fromRoute('system.status');
    $this->drupalGet($url);
    $this->assertSession()->statusCodeEquals(200);

    // Test that the page contains the GIT info section.
    $this->assertSession()->pageTextContains('GIT info');
  }

  /**
   * Test form submission.
   */
  public function testFormSubmission() {
    // Get form and check it loads correctly.
    $url = Url::fromRoute('gitinfo.settings');
    $this->drupalGet($url);
    $this->assertSession()->statusCodeEquals(200);
    $this->assertText('Connect with remote repos');
    // Empty form submission. Check presence of the default value.
    $this->drupalPostForm(NULL, [], 'Save configuration');
    $this->assertText('vendor');
    // Form validation testing of a non-existing directory rejection.
    $edit = ['extra_folders' => '/non-existing/directory'];
    $this->drupalPostForm(NULL, $edit, 'Save configuration');
    $this->assertText('Directory /non-existing/directory does not exist.');
    // Form validation testing of an invalid characters rejection.
    $edit = ['extra_folders' => '', 'aggregate_folders' => 'some/invalid/ch@r@ter$'];
    $this->drupalPostForm(NULL, $edit, 'Save configuration');
    $this->assertText('Directory some/invalid/ch@r@ter$ is invalid.');
    // Form validation testing of an invalid date format.
    $edit = [
      'extra_folders' => '',
      'aggregate_folders' => '',
      'exact_date_format' => 'l \t\h\e jS \of F Y h:i:s Agibberish',
    ];
    $this->drupalPostForm(NULL, $edit, 'Save configuration');
    $this->assertText('Invalid format.');
    // A correct form submission.
    $edit = [
      'extra_folders' => '',
      'aggregate_folders' => 'vendor',
      'number_commit_messages' => 0,
      'fuzzy_timestamp_granularity' => 9,
      'exact_date_format' => 'l \t\h\e jS \of F Y h:i:s A',
    ];
    $this->drupalPostForm(NULL, $edit, 'Save configuration');
    $this->assertText('The configuration options have been saved.');
  }

}
